
dm 'log;clear;out;clear;';
options nocenter ps=2000 nodate nonumber;
options formchar='           ' ls=150;

title 'Family distribution';
title2 '(without differentiating diagnostic criteria)';

/*prepare raw data*/
data fam;
  infile "chr1.pre";
  input pedigree$ id fid mid sex aff liab;
  n=1;
  if pedigree="" then delete;
  if aff=0 and liab=1 then affect=1; /*0 1*/
  if aff=1 and liab=1 then affect=2; /*1 1*/
  if aff=2 and liab=1 then affect=3; /*2 1*/
  if aff=2 and liab=2 then affect=4; /*2 2*/
  if aff=2 and liab=3 then affect=5; /*2 3*/
  if aff=2 and liab=4 then affect=6; /*2 4*/
  label affect='affection status'
        pedigree='pedigree id';
run;

/*prepare format*/
proc format;
  value aff
        1 = 'unknown'
        2 = 'unaffected'
        3 = 'Schizophrenia by narrow d.c.'
        4 = 'Schizophrenia by broad d.c.'
        5 = 'Bipolar by narrow d.c.'
        6 = 'Bipolar by broad d.c.';
run;

/*by sex*/
proc freq;
   table sex;
run;

/*by definitions*/
options missing=' ';
proc tabulate data=fam f=10. order=data noseps;
  class pedigree affect;
  format affect aff.;
  table pedigree all,affect all/rts=12;
  keylabel n=' ' all='total';
run;

proc freq data=fam noprint;
  table pedigree*affect/out=freq1;
run;

/*get family sizes and describe them*/
proc sort data=fam out=newfam;
  by pedigree;
run;

proc summary;
  var n;
  by pedigree;
  output out=nfam n=fsize;
run;

proc univariate;
  var fsize;
run;

/*by different definitions*/
title2 '(by different definitions)';

proc sort data=fam out=newfam;
  by pedigree;
run;

data newfam;
  merge newfam nfam (drop=_type_ _freq_);
  by pedigree;
run;

data freq2 (drop=_type_ _freq_);
  merge nfam freq1 (drop=percent);
  by pedigree;
run;

proc sort data=freq2;
  by affect pedigree;
run;

proc univariate data=freq2;
  by affect;
  var fsize;
  format affect aff.;
run;
