options nocenter nodate nonumber;

libname x '.';

* marker name repository;

data mname;
  set x.mname;model=1;output;
  set x.mname;model=2;output;
  set x.mname;model=3;output;
  set x.mname;model=4;output;
  set x.mname;model=5;output;
  set x.mname;model=6;output;
run;

* lod score summary;

data report;
  infile 'report.dat';
  label chr='chromosome';
  input chr$ model marker lod1-lod7;
  lod=max(of lod1-lod7);
  drop lod1-lod7;
run;

* basic check;

title 'Basic check of markers by chromosome';
proc tabulate data=report fc='           ' f=6. noseps;
  class chr model;
  table chr all,model all/rts=15;
  keylabel n=' ' all='total';
run;

* put together;

proc sort data=report;
  by chr model marker;
run;

proc sort data=mname;
  by chr model marker;
run;

data new;
  merge report mname;
  by chr model marker;
run;

title '2-point linkage result under six models';

* some refinements;

proc format;
  value modelf 1='Sch-Dom'
               2='Sch-Rec'
               3='Bip-Dom'
               4='Bip-Rec'
               5='Psy-Dom'
               6='Psy-Rec'
;
run;

proc tabulate f=8.2 fc='           ' order=data noseps;
  class chr model name;
  var lod;
  table chr,name=' ',model*lod=' ' lod=' '*max/box='Marker name';
  keylabel sum=' ' max='MOD';
  format model modelf.;
run;

data model1 model2 model3 model4 model5 model6;
  set new;
  select(model);
    when (1) output model1;
    when (2) output model2;
    when (3) output model3;
    when (4) output model4;
    when (5) output model5;
    when (6) output model6;
  end;
run;

data x.plot;
  merge model1(rename=(lod=lod1))
        model2(rename=(lod=lod2))
        model3(rename=(lod=lod3))
        model4(rename=(lod=lod4))
        model5(rename=(lod=lod5))
        model6(rename=(lod=lod6));
  by chr marker;
* if first.chr then chrn+1;
  mod=max(of lod1-lod6);
  array lod{6} lod1-lod6;
  do i=1 to 6;
     if mod=lod[i] then model=i;
  end;
  cmod=mod-log10(6);
  label mod='MOD score' cmod='CMOD score';
  drop i;
run;

proc sort data=x.plot;
  by chrn marker;
run;

proc format;
  value modf low-<1='<1' 1-<2='1-' 2-<3='2-' 3-high='3-';
run;

title 'MOD score >=2';
proc print data=x.plot noobs;
  var chr model name mod;
  where mod>=2;
run;

title 'MOD score by chromosome';
options missing=' ';
proc tabulate fc='           ' noseps missing f=5.;
  class chr mod;
  table chr all,mod all/rts=12;
  format mod modf.;
  keylabel n=' ' all='total';
run;

proc datasets;
  delete model1 model2 model3 model4 model5 model6;
run;

* invisible under batch mode;

goptions device=win;
symbol i=join;
legend1 label=('mod score');
legend2 label=('Sch-Dom');
legend3 label=('Sch-Rec');
legend4 label=('Bip-Dom');
legend5 label=('Bip-Rec');
legend6 label=('Psy-Dom');
legend7 label=('Psy-Rec');
title '2-point mod/cmod score';
proc gplot;
  by chr;
  plot (mod cmod)*marker/overlay vaxis=-3 to 3.6 vref=-2 0 2 3;
run cancel;
